=====================
Module **hybridLFPy**
=====================

Python module implementating a hybrid model scheme for predictions of
extracellular potentials (local field potentials, LFPs) of spiking
neuron network simulations. 


Development
-----------

The module hybridLFPy was mainly developed in the Computational Neuroscience
Group (http://compneuro.umb.no), Department of Mathemathical Sciences and
Technology (http://www.nmbu.no/imt), at the Norwegian University of Life
Sciences (http://www.nmbu.no), Aas, Norway, in collaboration with Institute of
Neuroscience and Medicine (INM-6) and Institute for Advanced Simulation (IAS-6),
Juelich Research Centre and JARA, Juelich, Germany
(http://www.fz-juelich.de/inm/inm-6/EN/).


Manuscript
----------

A preprint of our manuscript on the hybrid scheme implemented in ``hybridLFPy`` is available on arXiv.org at http://arxiv.org/abs/1511.01681

Citation:
Espen Hagen, David Dahmen, Maria L. Stavrinou, Henrik Linden, Tom Tetzlaff, Sacha Jennifer van Albada, Sonja Gruen, Markus Diesmann, Gaute T. Einevoll. Hybrid scheme for modeling local field potentials from point-neuron networks. arXiv:1511.01681 [q-bio.NC]

Bibtex source:
::
    
    @ARTICLE{2015arXiv151101681H,
       author = {{Hagen}, E. and {Dahmen}, D. and {Stavrinou}, M.~L. and {Lind{\'e}n}, H. and 
            {Tetzlaff}, T. and {van Albada}, S.~J. and {Gr{\"u}n}, S. and 
            {Diesmann}, M. and {Einevoll}, G.~T.},
        title = "{Hybrid scheme for modeling local field potentials from point-neuron networks}",
      journal = {ArXiv e-prints},
    archivePrefix = "arXiv",
       eprint = {1511.01681},
     primaryClass = "q-bio.NC",
     keywords = {Quantitative Biology - Neurons and Cognition},
         year = 2015,
        month = nov,
       adsurl = {http://adsabs.harvard.edu/abs/2015arXiv151101681H},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
    }    

Tutorial slides
---------------

Slides from OCNS 2015 meeting tutorial `T2:  Modeling and analysis of extracellular potentials <http://www.cnsorg.org/cns-2015-tutorials#t2>`_ hosted in Prague, Czech Republic on LFPy and hybridLFPy: `CNS2015_LFPy_tutorial.pdf  <http://LFPy.github.io/downloads/CNS2015_LFPy_tutorial.pdf>`_



License
-------

This software is released under the General Public License (see LICENSE file).


Warranty
--------

This software comes without any form of warranty. 


============
Installation
============

First download all the ``hybridLFPy`` source files using ``git``
(http://git-scm.com). Open a terminal window and type:
::
    
    cd $HOME/where/to/put/hybridLFPy
    git clone https://github.com/INM-6/hybridLFPy.git
    

To use ``hybridLFPy`` from any working folder without installing files, add this
path to ``$PYTHONPATH``. Edit your ``.bash_profile`` or similar file, and add:
::    
    
    export $PYTHONPATH=$PYTHONPATH:/PATH/TO/THIS/FOLDER:
    
Installing it is also possible, but not recommended as things might change with
any pull request from the repository:
::    
    
    (sudo) python setup.py install (--user)



examples folder
---------------

Some example script(s) on how to use this module



docs folder
-----------

Source files for autogenerated documentation using Sphinx.

To compile documentation source files in this directory using sphinx, use:
::

    sphinx-build -b html docs documentation
    

Online documentation
--------------------

The sphinx-generated html documentation can be accessed at
http://INM-6.github.io/hybridLFPy
